@@ -289,7 +289,7 @@ void App_Glom::init_menus()
 void App_Glom::on_menu_userlevel_developer()
 {
   if(m_pFrame)
-    m_pFrame->on_menu_userlevel_Developer(m_action_menu_userlevel_developer);
+    m_pFrame->on_menu_userlevel_Developer(m_action_menu_userlevel_developer, m_action_menu_userlevel_operator);
 }
 
 void App_Glom::on_menu_userlevel_operator()
@@ -357,7 +357,7 @@ bool App_Glom::on_document_load()
         connection_pool->set_host(pDocument->get_connection_server());
         connection_pool->set_user(pDocument->get_connection_user());
         connection_pool->set_database(pDocument->get_connection_database());
-        
+
         connection_pool->set_ready_to_connect(); //Box_DB::connect_to_server() will now attempt the connection-> Shared instances of m_Connection will also be usable.
 
         //Attempt to connect to the specified database:
@@ -374,16 +374,17 @@ bool App_Glom::on_document_load()
             //The connection to the server is OK, but the database is not there yet.
             //Ask the user if he wants to create it.
             //For instance, it might be an example document, whose database does not exist on his server yet.
-            
+
             Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "dialog_recreate_database");
             Gtk::Dialog* dialog = 0;
             refXml->get_widget("dialog_recreate_database", dialog);
             if(dialog)
             {
               int response = dialog->run();
+              dialog->set_transient_for(*this);
               delete dialog;
               dialog = 0;
-              
+
               if(response == Gtk::RESPONSE_CANCEL)
                 return false; //Close the document.
               else
@@ -391,8 +392,26 @@ bool App_Glom::on_document_load()
                 bool user_cancelled = false;
                 bool test = recreate_database(user_cancelled);
 
-                if(!test)
+                if(test)
                 {
+                  //If the database was successfully recreated.
+
+                  //Warn about read-only files, such as installed example files.
+                  Document_Glom::userLevelReason reason = Document_Glom::USER_LEVEL_REASON_UNKNOWN;
+                  AppState::userlevels userlevel = pDocument->get_userlevel(reason);
+                  if( (userlevel == AppState::USERLEVEL_OPERATOR) && (reason == Document_Glom::USER_LEVEL_REASON_FILE_READ_ONLY) )
+                  {
+                    Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(gettext("Creating from read-only file.")), true,  Gtk::MESSAGE_WARNING);
+                    dialog.set_secondary_text(gettext("This file is read only, so you will not be able to enter Developer mode to make design changes. Maybe this file is an installed example file. Therefore, you might want to create your own writeable copy of this file."));
+                    dialog.set_transient_for(*this);
+                    dialog.run();
+                    //TODO: Store a magic number in the database (a special table) and the file to check for mismatches.
+                  }
+                }
+                else
+                {
+                  //If the database was not successfully recreated:
+
                   if(!user_cancelled)
                   {
                     //Tell the user:
@@ -442,8 +461,16 @@ void App_Glom::statusbar_clear()
   statusbar_set_text("");
 }
 
-void App_Glom::on_userlevel_changed(AppState::userlevels userlevel)
+
+void App_Glom::on_userlevel_changed(AppState::userlevels /* userlevel */)
 {
+  update_userlevel_ui();
+}
+
+void App_Glom::update_userlevel_ui()
+{
+  AppState::userlevels userlevel = get_userlevel();
+  
   //Disable/Enable developer actions:
   for(type_listActions::iterator iter = m_listDeveloperActions.begin(); iter != m_listDeveloperActions.end(); ++iter)
   {
@@ -477,12 +504,12 @@ bool App_Glom::offer_new_or_existing()
   Gtk::Dialog* dialog = 0;
   refXml->get_widget("dialog_existing_or_new", dialog);
   dialog->set_transient_for(*this);
-  
+
   int response_id = dialog->run();
   delete dialog;
   dialog = 0;
-  
-  if(response_id ==1) //Open
+
+  if(response_id == 1) //Open
   {
     on_menu_file_open();
 
@@ -516,7 +543,8 @@ bool App_Glom::offer_new_or_existing()
         if(dialog)
         {
           std::auto_ptr<Dialog_NewDatabase> dialog_owner(dialog); //This will delete the dialog even when we return in the middle of this function.
-          
+          dialog->set_transient_for(*this);
+
           //Set suitable defaults:
           const Glib::ustring filename = document->get_name(); //Get the filename without the path and extension.
           dialog->set_input(filename, Base_DB::util_title_from_string( filename ) );
@@ -641,12 +669,12 @@ bool App_Glom::recreate_database(bool& user_cancelled)
   ConnectionPool* connection_pool = ConnectionPool::get_instance();
   if(!connection_pool)
     return false; //Impossible anyway.
-  
+
   //Check whether the database exists already.
   const Glib::ustring db_name = pDocument->get_connection_database();
   if(db_name.empty())
     return false;
-    
+
   connection_pool->set_database(db_name);
   try
   {
@@ -664,21 +692,21 @@ bool App_Glom::recreate_database(bool& user_cancelled)
       g_warning("App_Glom::recreate_database(): Failed because connection to server failed, without specifying a databse.");
       return false;
     }
-    
+
     //Otherwise continue, because we expected connect() to fail if the db does not exist yet.
   }
 
  //Create the database:
   connection_pool->set_database( Glib::ustring() );
   bool db_created = m_pFrame->create_database(db_name, false /* Don't ask for password etc again. */);
-  
+
   if(!db_created)
   {
     return false;
   }
   else
     connection_pool->set_database(db_name); //Specify the new database when connection from now on.
-               
+
   sharedptr<SharedConnection> sharedconnection;
   try
   {
@@ -692,7 +720,7 @@ bool App_Glom::recreate_database(bool& user_cancelled)
   }
 
   Bakery::BusyCursor(*this);
-   
+
   //Create each table:
   Document_Glom::type_listTableInfo tables = pDocument->get_tables();
   for(Document_Glom::type_listTableInfo::const_iterator iter = tables.begin(); iter != tables.end(); ++iter)
@@ -707,13 +735,13 @@ bool App_Glom::recreate_database(bool& user_cancelled)
     {
       //Create SQL to describe this field:
       Field field = *iter;
-     
+
       //The field has no gda type, so we set that:
       //This usually comes from the database, but that's a bit strange.
       Gnome::Gda::FieldAttributes info = field.get_field_info();
       info.set_gdatype( Field::get_gda_type_for_glom_type(field.get_glom_type()) );
       field.set_field_info(info);
-      
+
       Glib::ustring sql_field_description = field.get_name() + " " + field.get_sql_type();
 
       if(field.get_field_info().get_primary_key())
@@ -743,15 +771,23 @@ bool App_Glom::recreate_database(bool& user_cancelled)
     {
       table_creation_succeeded = false;
     }
-    
+
     if(!table_creation_succeeded)
     {
       g_warning("App_Glom::recreate_database(): CREATE TABLE failed with the newly-created database.");
       return false;
     }
-      
+
   } //for(tables)
 
+
+  //Create the developer group, and make this user a member of it:
+  //If we got this far then the user must really have developer privileges already:
+  m_pFrame->add_standard_groups();
+
+  Glib::ustring strQuery = "ALTER GROUP " GLOM_STANDARD_GROUP_NAME_DEVELOPER " ADD USER " + connection_pool->get_user();
+  m_pFrame->Query_execute(strQuery);
+
   return true; //All tables created successfully.
 }
 
@@ -767,3 +803,23 @@ AppState::userlevels App_Glom::get_userlevel() const
   else
     return AppState::USERLEVEL_DEVELOPER; //This should never happen.
 }
+
+void App_Glom::add_developer_action(const Glib::RefPtr<Gtk::Action>& refAction)
+{
+  //Prevent it from being added twice:
+  remove_developer_action(refAction);
+  
+  m_listDeveloperActions.push_back(refAction);
+}
+
+void App_Glom::remove_developer_action(const Glib::RefPtr<Gtk::Action>& refAction)
+{
+  for(type_listActions::iterator iter = m_listDeveloperActions.begin(); iter != m_listDeveloperActions.end(); ++iter)
+  {
+    if(*iter == refAction)
+    {
+      m_listDeveloperActions.erase(iter);
+      break;
+    }
+  }
+}
