@@ -21,7 +21,8 @@
 #include "box_data.h"
 #include "../data_structure/glomconversions.h"
 #include "../data_structure/layout/layoutitem_field.h"
-#include "../glom_python.h"
+#include "../python_embed/glom_python.h"
+#include <bakery/App/App_Gtk.h> //For util_bold_message().
 #include "config.h"
 #include <libintl.h>
 
@@ -223,12 +224,12 @@ bool Box_Data::confirm_discard_unstored_data() const
   if(get_unstored_data())
   {
     //Ask user to confirm loss of data:
-    Gtk::MessageDialog dialog(gettext("<b>No primary key value</b>"), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
+    Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(gettext("No primary key value")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
     dialog.set_secondary_text(gettext("This data can not be stored in the database because you have not provided a primary key.\nDo you really want to discard this data?"));
     //TODO: dialog.set_transient_for(*this);
     int iButton = dialog.run();
 
-    return (iButton == 0); //0 for YES, 1 for NO.
+    return (iButton == Gtk::RESPONSE_OK);
   }
   else
   {
@@ -247,7 +248,7 @@ void Box_Data::show_layout_dialog()
 
 void Box_Data::on_dialog_layout_hide()
 {
-  //Re-fill view, in case the layout has changed;
+  //Re-fill view, in case the layout has changed:
   fill_from_database();
 }
 
@@ -261,7 +262,7 @@ Box_Data::type_vecLayoutFields Box_Data::get_fields_to_show() const
     return get_table_fields_to_show(m_strTableName);
 }
 
-void Box_Data::get_table_fields_to_show_add_group(const Glib::ustring& table_name, const type_vecFields& all_db_fields, const LayoutGroup& group, Box_Data::type_vecLayoutFields& vecFields) const
+void Box_Data::get_table_fields_to_show_add_group(const Glib::ustring& table_name, const Privileges& table_privs, const type_vecFields& all_db_fields, const LayoutGroup& group, Box_Data::type_vecLayoutFields& vecFields) const
 {
   //g_warning("Box_Data::get_table_fields_to_show_add_group(): table_name=%s, all_db_fields.size()=%d, group.name=%s", table_name.c_str(), all_db_fields.size(), group.get_name().c_str());
 
@@ -294,6 +295,11 @@ void Box_Data::get_table_fields_to_show_add_group(const Glib::ustring& table_nam
             LayoutItem_Field layout_item = *item_field; //TODO_Performance: Reduce the copying.
             layout_item.m_field = field; //Fill in the full field information for later.
 
+            //TODO_Performance: We do this once for each related field, even if there are 2 from the same table:
+            const Privileges privs_related = get_current_privs(relationship.get_to_table());
+            layout_item.m_priv_view = privs_related.m_view;
+            layout_item.m_priv_edit = privs_related.m_edit;
+
             vecFields.push_back(layout_item);
           }
         }
@@ -307,6 +313,11 @@ void Box_Data::get_table_fields_to_show_add_group(const Glib::ustring& table_nam
         {
           LayoutItem_Field layout_item = *item_field; //TODO_Performance: Reduce the copying here.
           layout_item.m_field = *iterFind; //Fill the LayoutItem with the full field information.
+
+          //Prevent editing of the field if the user may not edit this table:
+          layout_item.m_priv_view = table_privs.m_view;
+          layout_item.m_priv_edit = table_privs.m_edit;
+
           vecFields.push_back(layout_item);
         }
       }
@@ -317,14 +328,14 @@ void Box_Data::get_table_fields_to_show_add_group(const Glib::ustring& table_nam
       if(item_group)
       {
         //Recurse:
-        get_table_fields_to_show_add_group(table_name, all_db_fields, *item_group, vecFields);
+        get_table_fields_to_show_add_group(table_name, table_privs, all_db_fields, *item_group, vecFields);
       }
     }
   }
 
   if(vecFields.empty())
   {
-    g_warning("Box_Data::get_table_fields_to_show_add_group(): Returning empty list.");
+    //g_warning("Box_Data::get_table_fields_to_show_add_group(): Returning empty list.");
   } 
 }
 
@@ -345,6 +356,8 @@ Box_Data::type_vecLayoutFields Box_Data::get_table_fields_to_show(const Glib::us
   //Get field definitions from the database, with corrections from the document:
   type_vecFields all_fields = get_fields_for_table(table_name);
 
+  const Privileges table_privs = get_current_privs(table_name);
+
   //Get fields that the document says we should show:
   type_vecLayoutFields result;
   const Document_Glom* pDoc = dynamic_cast<const Document_Glom*>(get_document());
@@ -363,6 +376,16 @@ Box_Data::type_vecLayoutFields Box_Data::get_table_fields_to_show(const Glib::us
         LayoutItem_Field layout_item;
         layout_item.set_name(primary_key_field_name);
         layout_item.m_field = all_fields[iPrimaryKey];
+
+        //Don't use thousands separators with ID numbers:
+        layout_item.m_numeric_format.m_use_thousands_separator = false;
+
+        layout_item.set_editable(true); //A sensible default.
+
+        //Prevent editing of the field if the user may not edit this table:
+        layout_item.m_priv_view = table_privs.m_view;
+        layout_item.m_priv_edit = table_privs.m_edit;
+
         result.push_back(layout_item);
       }
 
@@ -377,6 +400,12 @@ Box_Data::type_vecLayoutFields Box_Data::get_table_fields_to_show(const Glib::us
           layout_item.set_name(iter->get_name());
           layout_item.m_field = field_info;
 
+          layout_item.set_editable(true); //A sensible default.
+
+          //Prevent editing of the field if the user may not edit this table:
+          layout_item.m_priv_view = table_privs.m_view;
+          layout_item.m_priv_edit = table_privs.m_edit;
+
           result.push_back(layout_item);
         }
       }
@@ -393,7 +422,7 @@ Box_Data::type_vecLayoutFields Box_Data::get_table_fields_to_show(const Glib::us
         if(true) //!group.m_hidden)
         {
           //Get the fields:
-          get_table_fields_to_show_add_group(table_name, all_fields, group, result);
+          get_table_fields_to_show_add_group(table_name, table_privs, all_fields, group, result);
         }
       }
     }
@@ -401,7 +430,7 @@ Box_Data::type_vecLayoutFields Box_Data::get_table_fields_to_show(const Glib::us
 
   if(result.empty())
   {
-    g_warning("Box_Data::get_table_fields_to_show_add_group(): Returning empty list.");
+    //g_warning("Box_Data::get_table_fields_to_show_add_group(): Returning empty list.");
   }
 
   return result;
@@ -535,7 +564,7 @@ Gnome::Gda::Value Box_Data::get_lookup_value(const Relationship& relationship, c
 Document_Glom::type_mapLayoutGroupSequence Box_Data::get_data_layout_groups(const Glib::ustring& layout)
 {
   Document_Glom::type_mapLayoutGroupSequence layout_groups;
-  
+
   Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
   if(document)
   {
@@ -544,10 +573,12 @@ Document_Glom::type_mapLayoutGroupSequence Box_Data::get_data_layout_groups(cons
       //Get the layout information from the document:
       layout_groups = document->get_data_layout_groups_plus_new_fields(layout, m_strTableName);
 
+      const Privileges table_privs = get_current_privs(m_strTableName);
+
       //Fill in the field information for the fields mentioned in the layout:
       for(Document_Glom::type_mapLayoutGroupSequence::iterator iterGroups = layout_groups.begin(); iterGroups != layout_groups.end(); ++iterGroups)
       {
-        fill_layout_group_field_info(iterGroups->second);
+        fill_layout_group_field_info(iterGroups->second, table_privs);
       }
     }
   }
@@ -555,7 +586,7 @@ Document_Glom::type_mapLayoutGroupSequence Box_Data::get_data_layout_groups(cons
   return layout_groups;
 }
 
-void Box_Data::fill_layout_group_field_info(LayoutGroup& group)
+void Box_Data::fill_layout_group_field_info(LayoutGroup& group, const Privileges& table_privs)
 { 
   const Document_Glom* document = get_document();
 
@@ -581,6 +612,11 @@ void Box_Data::fill_layout_group_field_info(LayoutGroup& group)
           if(test)
           {
             item_field->m_field = field;
+
+            //TODO_Performance: Don't do this repeatedly for the same table.
+            const Privileges privs = get_current_privs(relationship.get_to_table());
+            item_field->m_priv_view = privs.m_view;
+            item_field->m_priv_edit = privs.m_edit;
           }
         }
       }
@@ -592,6 +628,8 @@ void Box_Data::fill_layout_group_field_info(LayoutGroup& group)
         if(found)
         {
           item_field->m_field = field; //TODO_Performance: Just use this as the output arg?
+          item_field->m_priv_view = table_privs.m_view;
+          item_field->m_priv_edit = table_privs.m_edit;
         }
       }
     }
@@ -601,7 +639,7 @@ void Box_Data::fill_layout_group_field_info(LayoutGroup& group)
       if(item_group) //If it is a group
       {
         //recurse, to fill the fields info in this group:
-        fill_layout_group_field_info(*item_group);
+        fill_layout_group_field_info(*item_group, table_privs);
       }
     }
   }
@@ -816,7 +854,7 @@ bool Box_Data::add_related_record_for_field(const LayoutItem_Field& layout_item_
     {
       //Warn the user:
       //TODO: Make the field insensitive until it can receive data, so people never see this dialog.
-      Gtk::MessageDialog dialog(gettext("<b>Related Record Does Not Exist</b>"), true);
+      Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(gettext("Related Record Does Not Exist")), true);
       dialog.set_secondary_text(gettext("Data may not be entered into this related field, because the related record does not yet exist, and the relationship does not allow automatic creation of new related records."));
       dialog.set_transient_for(*get_app_window());
       dialog.run();
@@ -835,7 +873,7 @@ bool Box_Data::add_related_record_for_field(const LayoutItem_Field& layout_item_
       {
         //Warn the user:
         //TODO: Make the field insensitive until it can receive data, so people never see this dialog.
-        Gtk::MessageDialog dialog(gettext("<b>Related Record Can Not Be Created</b>"), true);
+        Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(gettext("Related Record Can Not Be Created")), true);
         //TODO: This is a very complex error message:
         dialog.set_secondary_text(gettext("Data may not be entered into this related field, because the related record does not yet exist, and the key in the related record is auto-generated and therefore can not be created with the key value in this record."));
         dialog.set_transient_for(*get_app_window());
