@@ -19,6 +19,7 @@
  */
 
 #include "box_tables.h"
+#include <bakery/App/App_Gtk.h> //For util_bold_message().
 #include <libintl.h>
 
 Box_Tables::Box_Tables(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
@@ -30,8 +31,6 @@ Box_Tables::Box_Tables(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade:
   m_colTitle(0),
   m_colDefault(0)
 {
-  m_strHint = gettext("Select a table and click [Edit]. You may create a new table by entering the name in the last row.");
-
   //Get the Glade-instantiated widgets, and connect signal handlers:
   Gtk::Button* pButtonCancel = 0;
   refGlade->get_widget("button_cancel", pButtonCancel);
@@ -42,10 +41,10 @@ Box_Tables::Box_Tables(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade:
   pAligmentPlaceholder->add(m_AddDel);
 
   refGlade->get_widget("label_frame_title", m_pLabelFrameTitle);
-  
+
   refGlade->get_widget("checkbutton_show_hidden", m_pCheckButtonShowHidden);
   m_pCheckButtonShowHidden->signal_toggled().connect(sigc::mem_fun(*this, &Box_Tables::on_show_hidden_toggled));
-  
+
   m_AddDel.signal_user_added().connect(sigc::mem_fun(*this, &Box_Tables::on_adddel_Add));
   m_AddDel.signal_user_requested_delete().connect(sigc::mem_fun(*this, &Box_Tables::on_adddel_Delete));
   m_AddDel.signal_user_requested_edit().connect(sigc::mem_fun(*this, &Box_Tables::on_adddel_Edit));
@@ -69,13 +68,13 @@ void Box_Tables::fill_table_row(const Gtk::TreeModel::iterator& iter, const Tabl
     m_AddDel.set_value(iter, m_colDefault, table_info.m_default);
   }
 }
-  
+
 void Box_Tables::fill_from_database()
 {
   Bakery::BusyCursor(*get_app_window());
 
   Box_DB::fill_from_database();
-    
+
   //Enable/Disable extra widgets:
   bool developer_mode = (get_userlevel() == AppState::USERLEVEL_DEVELOPER);
 
@@ -84,7 +83,7 @@ void Box_Tables::fill_from_database()
     set_size_request(400, -1);
   else
     set_size_request(-1, -1);
-  
+
   m_pCheckButtonShowHidden->set_sensitive(developer_mode); //Operators have no choice - they can't see hidden tables ever.
   if(!developer_mode)
     m_pCheckButtonShowHidden->set_active(false); //Operators have no choice - they can't see hidden tables ever.
@@ -100,10 +99,10 @@ void Box_Tables::fill_from_database()
   m_colHidden = m_AddDel.add_column(gettext("Hidden"), AddDelColumnInfo::STYLE_Boolean, editable, visible_extras);
   m_colTitle =  m_AddDel.add_column(gettext("Title"), AddDelColumnInfo::STYLE_Text, editable, true);
   m_colDefault =  m_AddDel.add_column(gettext("Default"), AddDelColumnInfo::STYLE_Boolean,  editable, visible_extras);
-  
+
 
   //gettext("Server: ") +  m_strServerName + ", " + 
-  //Glib::ustring strTitle = Glib::ustring("<b>") + gettext("Tables from Database: ") + get_database_name() + "</b>";
+  //Glib::ustring strTitle = Glib::ustring("<b>") + gettext("Tables from Database: ") + get_database_name() + "");
   //m_pLabelFrameTitle->set_markup(strTitle);
 
   //Get the list of hidden tables:
@@ -114,8 +113,8 @@ void Box_Tables::fill_from_database()
     listTablesDocument = m_pDocument->get_tables();
   }
   else
-    g_warning("debug: m_pDocument is null");
-  
+    g_warning("Box_Tables::fill_from_database(): m_pDocument is null");
+
   //Get the list of tables in the database, from the server:
   sharedptr<SharedConnection> sharedconnection = connect_to_server();
   if(sharedconnection)
@@ -157,7 +156,7 @@ void Box_Tables::fill_from_database()
           TableInfo table_info;
           table_info.m_name = strName;
           table_info.m_hidden = true;
-          
+
           Gtk::TreeModel::iterator iter = m_AddDel.add_item(strName);
           fill_table_row(iter, table_info);
         }
@@ -243,7 +242,7 @@ void Box_Tables::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, cons
         {
           //Ask the user to confirm:
           Glib::ustring strMsg = gettext("Are you sure that you want to delete this table?\nTable name: ") + table_name;
-          Gtk::MessageDialog dialog(gettext("<b>Delete Table</b>"), true);
+          Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(gettext("Delete Table")), true);
           dialog.set_secondary_text(strMsg);
           dialog.set_transient_for(*get_app_window());
           int iButtonClicked = dialog.run();
@@ -252,6 +251,7 @@ void Box_Tables::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, cons
           if(iButtonClicked == Gtk::RESPONSE_OK)
           {
             Query_execute( "DROP TABLE " + table_name);
+            m_pDocument->remove_table(table_name); //Forget about it in the document too.
             something_changed = true;
           }
         }
@@ -277,7 +277,7 @@ void Box_Tables::on_adddel_Edit(const Gtk::TreeModel::iterator& row)
     if(!m_pDocument->get_table_is_known(table_name))
     {
        //TODO: Do not show tables that are not in the document.
-       Gtk::MessageDialog dialog(gettext("<b>Unknown Table</b>"), true);
+       Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(gettext("Unknown Table")), true);
        dialog.set_secondary_text(gettext("You can not open this table, because there is no information about this table in the document."));
        dialog.set_transient_for(*get_app_window());
        dialog.run();
